# Create a Bot Instance

```php
use skrtdev\NovaGram\Bot;
```
```php
new Bot(string $token, array $settings = [], $logger = null);
```

### Token
$token is the Bot's token generated by @BotFather

### Settings
$settings is an array which contains some NovaGram configurations.
> None of these fields is required

| key                         | type    | default                  | description                                                                                                                         |
|-----------------------------|---------|--------------------------|-------------------------------------------------------------------------------------------------------------------------------------|
| mode                        | integer | auto                     | Mode for update handling (or no handling at all)                                                                                    |
| json_payload                | boolean | `true`                   | Whether or not print json payload                                                                                                   |
| log_updates                 | integer | `false`                  | Chat id where raw json updates will be sent (set to false to disable)                                                               |
| debug                       | integer | `false`                  | Chat id where debug logs will be sent if an api error occurs (set to false to disable)                                              |
| async                       | bool    | `true`                   | Whether or not process updates concurrently                                                                                         |
| command_prefixes            | array   | `['/']`                  | Characters for commands prefixes. e.g. /start, .info                                                                                |
| bot_api_url                 | string  | https://api.telegram.org | Url for custom bot api                                                                                                              |
| restart_on_changes          | bool    | `false`                  | Auto restart when Bot file is edited                                                                                                |
| group_handlers              | bool    | `true`                   | Whether to execute all the handlers of an update in the same process (true), or fork a process for each handler (false)             |
| wait_handlers               | bool    | `false`                  | Whether to wait for handlers to finish when closing script                                                                          |
| threshold                   | int     | null                     | Defaults to 10 when using `getUpdates`. Amount of max seconds the script will wait instead of throwing a `TooManyRequestsException` |
| logger                      | int     | `Monolog\Logger::INFO`   | `Monolog\Logger` constant for logging                                                                                               |
| disable_ip_check            | boolean | `false`                  | Whether or not disable telegram ip check (could be useful in case of reverse proxy, such as ngrok)                                  |
| exceptions                  | bool    | `true`                   | Whether or not throw \skrtdev\Telegram\Exception(s) when API Errors occurs                                                          |
| database                    | array   | null                     | [Database](database.md) array connection info or instance of an existing `PDO` database (`novagram` will be used as prefix)         |
| parse_mode                  | string  | null                     | Default `parse_mode` for methods that require it                                                                                    |
| disable_web_page_preview    | bool    | null                     | Default `disable_web_page_preview` for methods that require it                                                                      |
| disable_notification        | bool    | null                     | Default `disable_notification` for methods that require it                                                                          |
| allow_sending_without_reply | bool    | null                     | Default `allow_sending_without_reply` for methods that require it                                                                   |
| only_if_banned              | bool    | null                     | Default `only_if_banned` for unbanChatMember method                                                                                 |

### Mode

Can be either `Bot::WEBHOOK`, `Bot::CLI` or `Bot::NONE`.
Normally it is automatic, and you can not specify it at all

### JSON Payload

JSON Payload is a different way to make API Calls.
In Webhooks, you can print a JSON-Encoded request directly in the webhook page, that will be processed by Telegram afterwards, without effectively making an API Call.
> Only One API Call can use JSON Payload simultaneously

#### Pro:
   * Since no HTTP Request is involved, using Payload speeds up the bot.

#### Cons:
   * The API Call is printed in the response, so you won't be able to get its result, nor know if an error occurs. Also, the API Call will be processed when the execution of the script finishes.

[How to make a JSON Payload API Call](requests.md)

## Examples

```php
use skrtdev\NovaGram\Bot;
$Bot = new Bot("YOUR_TOKEN", [
    "json_payload" => true,
    "debug" => 634408248,
    "parse_mode" => "HTML",
    "exceptions" => false
]);
```

In this example, `json_payload` is enabled, debug will be sent to `634408248`, default `parse_mode` is `HTML`, and no `\skrdtev\Telegram\Exception(s)` will be thrown when an API Error occurs

Go to [NovaGram Objects](objects.md)
